netapp_ontap.models.ndmp_mover API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.ndmp_mover`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NdmpMoverSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NdmpMover object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `bytes_moved GET POST PATCH`

    Indicates the NDMP mover bytes moved.

    Example: 645120

  `connection GET POST PATCH`

    Indicates the NDMP connection attributes.

  `mode GET POST PATCH`

    Indicates the NDMP mover mode of operation.

  `reason GET POST PATCH`

    Indicates the reason for the NDMP mover pause or halt.

  `state GET POST PATCH`

    Indicates the NDMP mover state.